@@ -26,7 +26,7 @@ def git_describe():
     try:
         # git describe?
         out = subprocess.check_output(["git", "describe"], stderr=subprocess.STDOUT)
-        return out.decode("utf-8").rstrip("\n")
+        return out.decode("utf-8").rstrip("\n")[1:]
     except Exception:
         return "git"
 
@@ -34,5 +34,5 @@ def git_describe():
 __author__ = "Rémi Duraffort"
 __description__ = "LAVA XML-RPC command line interface"
 __license__ = "AGPLv3+"
-__url__ = "https://git.lavasoftware.org/lava/lavacli.git"
-__version__ = "0.9.4"
+__url__ = "https://git.lavasoftware.org/lava/lavacli"
+__version__ = "0.9.5"
