@@ -71,8 +71,12 @@ def _load_configuration():
 
 def _save_configuration(config):
     config_dir = os.environ.get("XDG_CONFIG_HOME", "~/.config")
+    expanded_config_dir = os.path.expanduser(config_dir)
     config_filename = os.path.expanduser(os.path.join(config_dir, "lavacli.yaml"))
 
+    if not os.path.exists(expanded_config_dir):
+        os.makedirs(expanded_config_dir)
+
     with open(config_filename, "w", encoding="utf-8") as f_conf:
         f_conf.write(yaml.safe_dump(config, default_flow_style=False).rstrip("\n"))
 
