@@ -25,8 +25,10 @@ import pathlib
 import sys
 import time
 from urllib.parse import urlparse
+import xmlrpc.client
 import yaml
 
+from lavacli.utils import loader
 from lavacli.utils import print_u
 
 
@@ -276,6 +278,16 @@ def configure_parser(parser, version):
         help="Print the full url",
     )
 
+    if version >= (2019, 3):
+        # "validate"
+        jobs_validate = sub.add_parser("validate", help="validate the job definition")
+        jobs_validate.add_argument(
+            "definition", type=argparse.FileType("r"), help="job definition"
+        )
+        jobs_validate.add_argument(
+            "--strict", action="store_true", default=False, help="check in strict mode"
+        )
+
     if version >= (2018, 1):
         # "wait"
         jobs_wait = sub.add_parser("wait", help="wait for the job to finish")
@@ -490,10 +502,10 @@ def print_logs(logs, raw, filters):
 def _download_logs(proxy, version, job_id, start, end):
     if version >= (2018, 6):
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start, end)
-        logs = yaml.load(str(data), Loader=yaml.CLoader)
+        logs = yaml.load(str(data), Loader=loader())
     else:
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start)
-        logs = yaml.load(str(data), Loader=yaml.CLoader)
+        logs = yaml.load(str(data), Loader=loader())
         if end is not None and len(logs) >= end - start:
             if end < start:
                 end = start
@@ -691,23 +703,35 @@ def handle_show(proxy, options, config):
 
 
 def handle_submit(proxy, options, _):
+    prefix = ""
+    if options.print_url:
+        parsed = urlparse(options.uri)
+        host = parsed.netloc.split("@")[-1]
+        prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
+
     for definition in options.definition:
-        job_id = proxy.scheduler.jobs.submit(definition.read())
+        try:
+            job_id = proxy.scheduler.jobs.submit(definition.read())
+            if isinstance(job_id, list):
+                for job in job_id:
+                    print(prefix + str(job))
+            else:
+                print(prefix + str(job_id))
+        except xmlrpc.client.Error as exc:
+            print("Unable to submit %s" % definition.name)
 
-        prefix = ""
-        if options.print_url:
-            parsed = urlparse(options.uri)
-            host = parsed.netloc.split("@")[-1]
-            prefix = "%s://%s/scheduler/job/" % (parsed.scheme, host)
-
-        if isinstance(job_id, list):
-            for job in job_id:
-                print(prefix + str(job))
-        else:
-            print(prefix + str(job_id))
     return 0
 
 
+def handle_validate(proxy, options, _):
+    ret = proxy.scheduler.jobs.validate(options.definition.read(), options.strict)
+    if not ret:
+        return 0
+    print("key: %s" % ".".join(ret["path"]))
+    print("msg: %s" % ret["msg"])
+    return 1
+
+
 def handle_wait(proxy, options, _):
     job = proxy.scheduler.jobs.show(options.job_id)
     old_state = ""
@@ -739,6 +763,7 @@ def handle(proxy, options, config):
         "run": handle_run,
         "show": handle_show,
         "submit": handle_submit,
+        "validate": handle_validate,
         "wait": handle_wait,
     }
     return handlers[options.sub_sub_command](proxy, options, config)
