@@ -17,22 +17,20 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
-from contextlib import suppress
-import os
+import contextlib
+import pathlib
 import shutil
 import time
 import xmlrpc.client
 import yaml
 
-from lavacli.utils import VERSION_2017_12
-
 
 def configure_parser(parser, version):
     sub = parser.add_subparsers(dest="sub_sub_command", help="Sub commands")
     sub.required = True
 
     # "active"
-    if version >= VERSION_2017_12:
+    if version >= (2017, 12):
         sub.add_parser("active", help="activate the system")
 
     #  "api"
@@ -41,24 +39,36 @@ def configure_parser(parser, version):
     # "export"
     sys_export = sub.add_parser("export", help="export server configuration")
     sys_export.add_argument("name", help="name of the export")
-    sys_export.add_argument("--full", default=False, action="store_true",
-                            help="do a full export, including retired devices")
+    sys_export.add_argument(
+        "--full",
+        default=False,
+        action="store_true",
+        help="do a full export, including retired devices",
+    )
 
     # "import"
     # sub.add_parser("import", help="import server configuration")
 
     # "maintenance"
-    if version >= VERSION_2017_12:
+    if version >= (2017, 12):
         sys_maintenance = sub.add_parser("maintenance", help="maintenance the system")
-        sys_maintenance.add_argument("--force", default=False, action="store_true",
-                                     help="force maintenance by canceling jobs")
-        sys_maintenance.add_argument("--exclude", default=None,
-                                     help="comma seperated list of workers to keep untouched")
+        sys_maintenance.add_argument(
+            "--force",
+            default=False,
+            action="store_true",
+            help="force maintenance by canceling jobs",
+        )
+        sys_maintenance.add_argument(
+            "--exclude",
+            default=None,
+            help="comma seperated list of workers to keep untouched",
+        )
 
     # "methods"
     sys_methods = sub.add_parser("methods", help="list methods")
-    sys_sub = sys_methods.add_subparsers(dest="sub_sub_sub_command",
-                                         help="Sub commands")
+    sys_sub = sys_methods.add_subparsers(
+        dest="sub_sub_sub_command", help="Sub commands"
+    )
     sys_sub.required = True
     sys_sub.add_parser("list", help="list available methods")
 
@@ -95,10 +105,11 @@ def handle_api(proxy, _, __):
 
 def handle_export(proxy, options, config):
     print("Export to %s" % options.name)
-    with suppress(FileNotFoundError):
-        shutil.rmtree(options.name)
-    os.mkdir(options.name)
-    os.chdir(options.name)
+    dest = pathlib.Path(options.name)
+    with contextlib.suppress(FileNotFoundError):
+        shutil.rmtree(str(dest))
+    with contextlib.suppress(FileExistsError):
+        dest.mkdir(mode=0o755)
 
     print("Listing aliases")
     aliases = []
@@ -117,29 +128,41 @@ def handle_export(proxy, options, config):
     for worker in proxy.scheduler.workers.list():
         print("* %s" % worker)
         w = proxy.scheduler.workers.show(worker)
-        if config["version"] >= VERSION_2017_12:
-            workers.append({"hostname": w["hostname"],
-                            "description": w["description"],
-                            "state": w["state"],
-                            "health": w["health"]})
+        if config["version"] >= (2017, 12):
+            workers.append(
+                {
+                    "hostname": w["hostname"],
+                    "description": w["description"],
+                    "state": w["state"],
+                    "health": w["health"],
+                }
+            )
         else:
-            workers.append({"hostname": w["hostname"],
-                            "description": w["description"],
-                            "master": w["master"],
-                            "hidden": w["hidden"]})
+            workers.append(
+                {
+                    "hostname": w["hostname"],
+                    "description": w["description"],
+                    "master": w["master"],
+                    "hidden": w["hidden"],
+                }
+            )
 
     print("Listing device-types")
-    os.mkdir("device-types")
+    (dest / "device-types").mkdir(mode=0o755)
     device_types = []
     for device_type in proxy.scheduler.device_types.list():
         print("* %s" % device_type["name"])
         dt = proxy.scheduler.device_types.show(device_type["name"])
-        device_types.append({"name": dt["name"],
-                             "description": dt["description"],
-                             "display": dt["display"],
-                             "health_disabled": dt["health_disabled"],
-                             "owners_only": dt["owners_only"],
-                             "aliases": dt["aliases"]})
+        device_types.append(
+            {
+                "name": dt["name"],
+                "description": dt["description"],
+                "display": dt["display"],
+                "health_disabled": dt["health_disabled"],
+                "owners_only": dt["owners_only"],
+                "aliases": dt["aliases"],
+            }
+        )
 
         try:
             dt_template = proxy.scheduler.device_types.get_template(dt["name"])
@@ -148,27 +171,32 @@ def handle_export(proxy, options, config):
                 print("  => No template found")
                 continue
             raise
-        with open(os.path.join("device-types", dt["name"] + ".jinja2"),
-                  "w", encoding="utf-8") as f_out:
+        with (dest / "device-types" / ("%s.jinja2" % dt["name"])).open(
+            "w", encoding="utf-8"
+        ) as f_out:
             f_out.write(str(dt_template))
 
     print("Listing devices")
-    os.mkdir("devices")
+    (dest / "devices").mkdir(mode=0o755)
     devices = []
     for device in proxy.scheduler.devices.list(options.full):
         print("* %s" % device["hostname"])
         d = proxy.scheduler.devices.show(device["hostname"])
-        devices.append({"hostname": d["hostname"],
-                        "description": d["description"],
-                        "device_type": d["device_type"],
-                        "pipeline": d["pipeline"],
-                        "worker": d["worker"],
-                        "state": d["state"],
-                        "health": d["health"],
-                        "public": d["public"],
-                        "user": d["user"],
-                        "group": d["group"],
-                        "tags": d["tags"]})
+        devices.append(
+            {
+                "hostname": d["hostname"],
+                "description": d["description"],
+                "device_type": d["device_type"],
+                "pipeline": d["pipeline"],
+                "worker": d["worker"],
+                "state": d["state"],
+                "health": d["health"],
+                "public": d["public"],
+                "user": d["user"],
+                "group": d["group"],
+                "tags": d["tags"],
+            }
+        )
 
         try:
             device_dict = proxy.scheduler.devices.get_dictionary(device["hostname"])
@@ -177,19 +205,23 @@ def handle_export(proxy, options, config):
                 print("  => No device dict found")
                 continue
             raise
-        with open(os.path.join("devices", device["hostname"] + ".jinja2"),
-                  "w", encoding="utf-8") as f_out:
+        with (dest / "devices" / ("%s.jinja2" % device["hostname"])).open(
+            "w", encoding="utf-8"
+        ) as f_out:
             f_out.write(str(device_dict))
 
-    export = {"aliases": aliases,
-              "devices": devices,
-              "device-types": device_types,
-              "tags": tags,
-              "workers": workers}
+    export = {
+        "aliases": aliases,
+        "devices": devices,
+        "device-types": device_types,
+        "tags": tags,
+        "workers": workers,
+    }
 
     # Dump the configuration
-    with open("instance.yaml", "w", encoding="utf-8") as f_out:
+    with (dest / "instance.yaml").open("w", encoding="utf-8") as f_out:
         f_out.write(yaml.dump(export).rstrip("\n"))
+    return 0
 
 
 def handle_maintenance(proxy, options, _):
@@ -197,7 +229,7 @@ def handle_maintenance(proxy, options, _):
     workers = proxy.scheduler.workers.list()
     excluded_workers = []
     if options.exclude:
-        excluded_workers = options.exclude.split(',')
+        excluded_workers = options.exclude.split(",")
     for worker in workers:
         if worker in excluded_workers:
             print("* %s [SKIP]" % worker)
@@ -226,6 +258,7 @@ def handle_maintenance(proxy, options, _):
             while proxy.scheduler.jobs.show(current_job)["state"] != "Finished":
                 print("---> waiting")
                 time.sleep(5)
+    return 0
 
 
 def handle_methods(proxy, options, _):
@@ -238,6 +271,7 @@ def handle_methods(proxy, options, _):
         methods = proxy.system.listMethods()
         for method in methods:
             print(method)
+    return 0
 
 
 def handle_version(proxy, _, __):
@@ -262,6 +296,6 @@ def handle(proxy, options, config):
         "maintenance": handle_maintenance,
         "methods": handle_methods,
         "version": handle_version,
-        "whoami": handle_whoami
+        "whoami": handle_whoami,
     }
     return handlers[options.sub_sub_command](proxy, options, config)
