@@ -18,6 +18,7 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import re
+import yaml
 
 
 def print_u(string):
@@ -39,3 +40,11 @@ def parse_version(version):
         return VERSION_LATEST
     res = m.groupdict()
     return (int(res["major"]), int(res["minor"]))
+
+
+def loader():
+    try:
+        return yaml.CLoader
+    except AttributeError:
+        # TODO log a warning on stderr
+        return yaml.Loader
